/*
 *  Copyright (C) 2016 Damir Porobic <https://github.com/damirporobic>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef SCRIBBLEAREA_H
#define SCRIBBLEAREA_H

#include <QtGui>
#include <QGraphicsScene>

#include "PaintStroke.h"
#include "widgets/CustomCursor.h"

class PaintArea : public QGraphicsScene
{
    Q_OBJECT
public:
    PaintArea();
    enum PaintMode { Pen, Marker, Erase };
    void loadCapture ( QPixmap );
    QSize getAreaSize();
    void setPaintMode ( enum PaintMode );
    PaintMode getPaintMode();
    QImage exportAsImage();
    void setPenProperties ( QColor, int );
    QPen getPenProperties();
    void setMarkerProperties ( QColor, int );
    QPen getMarkerProperties();

signals:
    void imageChanged();

protected:
    virtual void mousePressEvent ( QGraphicsSceneMouseEvent * );
    virtual void mouseMoveEvent ( QGraphicsSceneMouseEvent * );
    virtual void mouseReleaseEvent ( QGraphicsSceneMouseEvent * );
    virtual void keyPressEvent ( QKeyEvent * );
    virtual void keyReleaseEvent ( QKeyEvent * );
    virtual bool event(QEvent * );

private:
    PaintStroke  *mCurrentPaintStroke;
    QPen         *mPen;
    QPen         *mMarker;
    CustomCursor *mCursor;
    bool          mIsSnapping;
    PaintMode     mCurrentPaintMode;
    void addNewPaintStroke ( QPointF );
    void addToCurrentPaintStroke ( QPointF );
    bool erasePaintStroke ( QPointF );
    void setCursorOnPaintArea();
    CustomCursor* getCursor();
};

#endif // SCRIBBLEAREA_H
